==> ecp_sync_plugin-3.2.2.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/CameraBasfActivity.java <==
package ecp.vcs.com.ecpsyncplugin;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.media.Ringtone;
import android.media.RingtoneManager;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;

import android.util.Log;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.google.zxing.Result;

import org.json.JSONArray;

import java.util.ArrayList;

import androidx.core.content.ContextCompat;
import me.dm7.barcodescanner.zxing.ZXingScannerView;

public class CameraBasfActivity extends Activity implements ZXingScannerView.ResultHandler {

    private ZXingScannerView mScannerView;
    ArrayList<String> scannedItems = new ArrayList<>();
    TextView textViewCount;
    String isSingleScan;
    String isPlaySound;
    String isOnFlase;

    @Override
    public void onCreate(Bundle state) {

        super.onCreate(state);

        Log.e("inside", "CameraBasfActivity");

        isSingleScan = getIntent().getExtras().getString("isSingleScan", "false");
        isPlaySound = getIntent().getExtras().getString("isPlaySound", "false");
        isOnFlase = getIntent().getExtras().getString("isOnFlase", "false");
        String themeColor = getIntent().getExtras().getString("themeColor", "false");

        //mScannerView = new ZXingScannerView(this);   // Programmatically initialize the scanner view
        //setContentView(mScannerView);                // Set the scanner view as the content view
        // Set the scanner view as the content view
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP)
            getWindow().setStatusBarColor(Color.parseColor(themeColor.equalsIgnoreCase("") ? "#004a96" : themeColor));
        setContentView(R.layout.layout_scan);

        assert getActionBar() != null;
        getActionBar().setTitle("");
        getActionBar().setDisplayHomeAsUpEnabled(true);
        //getActionBar().setHomeAsUpIndicator(R.drawable.back_dark);
        getActionBar().setBackgroundDrawable(new ColorDrawable(Color.parseColor(themeColor.equalsIgnoreCase("") ? "#004a96" : themeColor)));

        LinearLayout cam = (LinearLayout) findViewById(R.id.viewCam);
        Button btnNext = (Button) findViewById(R.id.btnNext);
        textViewCount = (TextView) findViewById(R.id.countText);
        btnNext.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                try {
                    Log.e("btnNext", "onClick");
                    Intent intent = new Intent("ScanResult");
                    if (scannedItems.size() > 0) {
                        JSONArray mJSONArray = new JSONArray(scannedItems);
                        intent.putExtra("JSONDATA", "" + mJSONArray.toString());
                    } else
                        intent.putExtra("JSONDATA", "");

                    intent.putExtra("SCAN", "DONE");
                    sendBroadcast(intent);
                    finish();
                } catch (Exception e) {
                    e.printStackTrace();
                    Intent intent = new Intent("ScanResult");
                    intent.putExtra("SCAN", "ERROR");
                    intent.putExtra("JSONDATA", "100");
                    sendBroadcast(intent);
                    finish();
                }
            }
        });
        //cam = mScannerView;
        //((ZXingScannerView) cam).addView(mScannerView);
        mScannerView = new ZXingScannerView(this);
        mScannerView.setAutoFocus(true);
        mScannerView.setFlash(Boolean.parseBoolean(isOnFlase));
        mScannerView.setBorderColor(Color.parseColor("#004a96"));
        mScannerView.setLaserEnabled(true);
        mScannerView.setSquareViewFinder(true);
        //mScannerView.buildLuminanceSource(null, 0, 0);
        cam.addView(mScannerView);

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (item.getItemId() == android.R.id.home) {
            Intent intent = new Intent("ScanResult");
            intent.putExtra("SCAN", "DONE");
            intent.putExtra("JSONDATA", "0");
            sendBroadcast(intent);
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onResume() {
        super.onResume();
        mScannerView.setResultHandler(this); // Register ourselves as a handler for scan results.
        mScannerView.startCamera();          // Start camera on resume
    }

    @Override
    public void onPause() {
        super.onPause();
        mScannerView.stopCamera();           // Stop camera on pause
    }

    @Override
    public void handleResult(Result rawResult) {
        Log.v("Scan", rawResult.getText()); // Prints scan results
        Log.v("Scan", rawResult.getBarcodeFormat().toString()); // Prints the scan format (qrcode, pdf417 etc.)
        String finalCode = Utils.getSerialNoFromBarcode(rawResult.getText(), true);
        Log.v("Scan finalCode", String.valueOf(finalCode));
        // If you would like to resume scanning, call this method below:
        if (!scannedItems.contains(finalCode)) {
            scannedItems.add(finalCode);
            textViewCount.setText(String.valueOf(scannedItems.size()));

            if (Boolean.parseBoolean(isPlaySound)) {
                try {
                    Uri notification = RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION);
                    Ringtone r = RingtoneManager.getRingtone(getApplicationContext(), notification);
                    r.play();
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }


        mScannerView.resumeCameraPreview(this);
    }

    /*@Override
    public void handleResult(ZXingScannerView.ResultHandler rawResult) {
        // Do something with the result here
        Log.v(TAG, rawResult.getText()); // Prints scan results
        Log.v(TAG, rawResult.getBarcodeFormat().toString()); // Prints the scan format (qrcode, pdf417 etc.)

        // If you would like to resume scanning, call this method below:
        mScannerView.resumeCameraPreview(this);
    }*/
}

==> ecp_sync_plugin-3.5.6.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/CameraBasfActivity.java <==
package ecp.vcs.com.ecpsyncplugin;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.media.Ringtone;
import android.media.RingtoneManager;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;

import android.util.Log;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.google.zxing.Result;

import org.json.JSONArray;

import java.util.ArrayList;


import me.dm7.barcodescanner.zxing.ZXingScannerView;

public class CameraBasfActivity extends Activity implements ZXingScannerView.ResultHandler {

    private ZXingScannerView mScannerView;
    ArrayList<String> scannedItems = new ArrayList<>();
    TextView textViewCount;
    String isSingleScan;
    String isPlaySound;
    String isOnFlase;

    @Override
    public void onCreate(Bundle state) {

        super.onCreate(state);

        Log.e("inside", "CameraBasfActivity");

        isSingleScan = getIntent().getExtras().getString("isSingleScan", "false");
        isPlaySound = getIntent().getExtras().getString("isPlaySound", "false");
        isOnFlase = getIntent().getExtras().getString("isOnFlase", "false");
        String themeColor = getIntent().getExtras().getString("themeColor", "false");

        //mScannerView = new ZXingScannerView(this);   // Programmatically initialize the scanner view
        //setContentView(mScannerView);                // Set the scanner view as the content view
        // Set the scanner view as the content view
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP)
            getWindow().setStatusBarColor(Color.parseColor(themeColor.equalsIgnoreCase("") ? "#004a96" : themeColor));
        setContentView(R.layout.layout_scan);

        assert getActionBar() != null;
        getActionBar().setTitle("");
        getActionBar().setDisplayHomeAsUpEnabled(true);
        //getActionBar().setHomeAsUpIndicator(R.drawable.back_dark);
        getActionBar().setBackgroundDrawable(new ColorDrawable(Color.parseColor(themeColor.equalsIgnoreCase("") ? "#004a96" : themeColor)));

        LinearLayout cam = findViewById(R.id.viewCam);
        Button btnNext = findViewById(R.id.btnNext);
        textViewCount = findViewById(R.id.countText);
        btnNext.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                doneCall();
            }
        });
        //cam = mScannerView;
        //((ZXingScannerView) cam).addView(mScannerView);
        mScannerView = new ZXingScannerView(this);
        mScannerView.setAutoFocus(true);
        mScannerView.setFlash(Boolean.parseBoolean(isOnFlase));
        mScannerView.setBorderColor(Color.parseColor("#004a96"));
        mScannerView.setLaserEnabled(true);
        mScannerView.setSquareViewFinder(true);
        //mScannerView.buildLuminanceSource(null, 0, 0);
        cam.addView(mScannerView);

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (item.getItemId() == android.R.id.home) {
            Intent intent = new Intent("ScanResult");
            intent.putExtra("SCAN", "DONE");
            intent.putExtra("JSONDATA", "0");
            sendBroadcast(intent);
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onResume() {
        super.onResume();
        mScannerView.setResultHandler(this); // Register ourselves as a handler for scan results.
        mScannerView.startCamera();          // Start camera on resume
    }

    @Override
    public void onPause() {
        super.onPause();
        mScannerView.stopCamera();           // Stop camera on pause
    }

    void doneCall() {
        try {
            Log.e("btnNext", "onClick");
            Intent intent = new Intent("ScanResult");
            if (scannedItems.size() > 0) {
                JSONArray mJSONArray = new JSONArray(scannedItems);
                intent.putExtra("JSONDATA", "" + mJSONArray.toString());
            } else {
                intent.putExtra("JSONDATA", "");
            }
            intent.putExtra("SCAN", "DONE");
            sendBroadcast(intent);
            finish();
        } catch (Exception e) {
            e.printStackTrace();
            Intent intent = new Intent("ScanResult");
            intent.putExtra("SCAN", "ERROR");
            intent.putExtra("JSONDATA", "100");
            sendBroadcast(intent);
            finish();
        }
    }

    @Override
    public void handleResult(Result rawResult) {
        Log.v("Scan", rawResult.getText()); // Prints scan results
        Log.v("Scan", rawResult.getBarcodeFormat().toString()); // Prints the scan format (qrcode, pdf417 etc.)
        String finalCode = Utils.getSerialNoFromBarcode(rawResult.getText(), true);
        Log.v("Scan finalCode", String.valueOf(finalCode));
        // If you would like to resume scanning, call this method below:
        if (!scannedItems.contains(finalCode)) {
            scannedItems.add(finalCode);
            textViewCount.setText(String.valueOf(scannedItems.size()));
            if (Boolean.parseBoolean(isPlaySound)) {
                try {
                    Uri notification = RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION);
                    Ringtone r = RingtoneManager.getRingtone(getApplicationContext(), notification);
                    r.play();
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }

            if (Boolean.parseBoolean(isSingleScan)) {
                if (scannedItems.size() > 0) {
                    doneCall();
                }
            }
        }
        mScannerView.resumeCameraPreview(this);
    }

    /*@Override
    public void handleResult(ZXingScannerView.ResultHandler rawResult) {
        // Do something with the result here
        Log.v(TAG, rawResult.getText()); // Prints scan results
        Log.v(TAG, rawResult.getBarcodeFormat().toString()); // Prints the scan format (qrcode, pdf417 etc.)

        // If you would like to resume scanning, call this method below:
        mScannerView.resumeCameraPreview(this);
    }*/
}
